@@ -10,14 +10,22 @@ Access MercadoPago for payments integration
 
 """
 class MP:
+    version = "0.1.8"
     __access_data = None
+    __sandbox = False
 
     def __init__(self, client_id, client_secret):
         self.__client_id = client_id
         self.__client_secret = client_secret
-        self.__rest_client = self.__RestClient()
+        self.__rest_client = self.__RestClient(self)
+
+    def sandbox_mode(self, enable=None):
+        if not enable is None:
+            self.__sandbox = enable == True
+
+        return self.__sandbox
         
-    def __get_access_token(self):
+    def get_access_token(self):
         app_client_values = {
                            "client_id": self.__client_id,
                            "client_secret": self.__client_secret,
@@ -30,7 +38,7 @@ class MP:
             self.__access_data = access_data["response"]
             return  self.__access_data["access_token"]
         else:
-            raise Exception(json.dumps(access_data))
+            raise Exception(access_data)
         
     """
     Get information for specific payment
@@ -40,11 +48,13 @@ class MP:
     """    
     def get_payment_info(self, id):
         try:
-            access_token = self.__get_access_token()
-        except Exception as e:
-            return e
+            access_token = self.get_access_token()
+        except Exception,e:
+            raise e
         
-        payment_info = self.__rest_client.get("/collections/notifications/"+id+"?access_token="+access_token)
+        uri_prefix = "/sandbox" if self.__sandbox else ""
+
+        payment_info = self.__rest_client.get(uri_prefix+"/collections/notifications/"+id+"?access_token="+access_token)
         return payment_info
     
     """
@@ -55,9 +65,9 @@ class MP:
     """    
     def refund_payment(self, id):
         try:
-            access_token = self.__get_access_token()
-        except Exception as e:
-            return e
+            access_token = self.get_access_token()
+        except Exception,e:
+            raise e
 
         refund_status = {"status":"refunded"}
         
@@ -72,9 +82,9 @@ class MP:
     """    
     def cancel_payment(self, id):
         try:
-            access_token = self.__get_access_token()
-        except Exception as e:
-            return e
+            access_token = self.get_access_token()
+        except Exception,e:
+            raise e
 
         cancel_status = {"status":"cancelled"}
         
@@ -91,15 +101,17 @@ class MP:
     """
     def search_payment(self, filters, offset=0, limit=0):
         try:
-            access_token = self.__get_access_token()
-        except Exception as e:
-            return e
+            access_token = self.get_access_token()
+        except Exception,e:
+            raise e
 
         filters["access_token"] = access_token
         filters["offset"] = offset
         filters["limit"] = limit
         
-        payment_result = self.__rest_client.get("/collections/search", filters)
+        uri_prefix = "/sandbox" if self.__sandbox else ""
+
+        payment_result = self.__rest_client.get(uri_prefix+"/collections/search", filters)
         return payment_result        
         
     """
@@ -110,9 +122,9 @@ class MP:
     """
     def create_preference(self, preference):
         try:
-            access_token = self.__get_access_token()
-        except Exception as e:
-            return e
+            access_token = self.get_access_token()
+        except Exception,e:
+            raise e
 
         preference_result = self.__rest_client.post("/checkout/preferences?access_token="+access_token, preference)
         return preference_result
@@ -126,9 +138,9 @@ class MP:
     """
     def update_preference(self, id, preference):
         try:
-            access_token = self.__get_access_token()
-        except Exception as e:
-            return e
+            access_token = self.get_access_token()
+        except Exception,e:
+            raise e
         
         preference_result = self.__rest_client.put("/checkout/preferences/"+id+"?access_token="+access_token, preference)
         return preference_result
@@ -142,9 +154,9 @@ class MP:
     """
     def get_preference(self, id):
         try:
-            access_token = self.__get_access_token()
-        except Exception as e:
-            return e
+            access_token = self.get_access_token()
+        except Exception,e:
+            raise e
         
         preference_result = self.__rest_client.get("/checkout/preferences/"+id+"?access_token="+access_token)
         return preference_result
@@ -154,9 +166,14 @@ class MP:
         __API_BASE_URL = "https://api.mercadolibre.com"
         MIME_JSON = "application/json"
         MIME_FORM = "application/x-www-form-urlencoded"
+
+        def __init__(self, outer):
+            self.__outer = outer
+            self.USER_AGENT = "MercadoPago Python SDK v"+self.__outer.version
+
         
         def get(self, uri, data=None):
-            api_result = requests.get(self.__API_BASE_URL+uri, params=data, headers={'Accept':self.MIME_JSON})
+            api_result = requests.get(self.__API_BASE_URL+uri, params=data, headers={'User-Agent':self.USER_AGENT, 'Accept':self.MIME_JSON})
 
             response = {
                 "status": api_result.status_code,
@@ -169,7 +186,7 @@ class MP:
             if data is not None and content_type == self.MIME_JSON:
                 data = JSONEncoder().encode(data)
 
-            api_result = requests.post(self.__API_BASE_URL+uri, data=data, headers={'Content-type':content_type, 'Accept':self.MIME_JSON})
+            api_result = requests.post(self.__API_BASE_URL+uri, data=data, headers={'User-Agent':self.USER_AGENT, 'Content-type':content_type, 'Accept':self.MIME_JSON})
 
             response = {
                 "status": api_result.status_code,
@@ -182,7 +199,7 @@ class MP:
             if data is not None and content_type == self.MIME_JSON:
                 data = JSONEncoder().encode(data)
 
-            api_result = requests.put(self.__API_BASE_URL+uri, data=data, headers={'Content-type':content_type, 'Accept':self.MIME_JSON})
+            api_result = requests.put(self.__API_BASE_URL+uri, data=data, headers={'User-Agent':self.USER_AGENT, 'Content-type':content_type, 'Accept':self.MIME_JSON})
 
             response = {
                 "status": api_result.status_code,
